from json import loads
from .constants import SESSION, REMOTE


def get(q: str, limit: int = 250) -> dict:
    q = q.split('/')
    q = f"{REMOTE}/users/{q[0]}/feeds/{q[1]}?limit={limit}"
    rv = SESSION.get(q)
    if rv.status_code != 200:
        raise ConnectionError('Something is wrong on the server end')

    return loads(rv.text)


def create(user: str, name:str , description:str = None) -> dict:
    uri = REMOTE + f'/users/{user}/feeds'
    rv = SESSION.post(uri, {
        'feed': {
            'name': name,
            'description': description
        }
    })
    return loads(rv.text)





from json import loads, dumps
from cachetools import TTLCache, cached
from pprint import pprint

from csirtgsdk.constants import HEADERS, CACHE_TTL, CACHE_MAX_SIZE, \
    REMOTE, TOKEN, SESSION

from .feed import create as create_feed, get as get_feed
from .indicator import create as create_indicator


@cached(TTLCache(maxsize=CACHE_MAX_SIZE, ttl=CACHE_TTL))
def search(q):
    rv = SESSION.get(REMOTE + '/search' + '?q=' + q)
    if rv.status_code != 200:
        raise ConnectionError('Something is wrong on the server end')

    return loads(rv.text)


@cached(TTLCache(maxsize=CACHE_MAX_SIZE, ttl=CACHE_TTL))
def risk(q, v=False):
    if v:
        v = '1'
    else:
        v = '0'

    rv = SESSION.get(REMOTE + '/risk', params={'q': q, 'v': v})
    if rv.status_code != 200:
        raise ConnectionError('Something is wrong on the server end')

    return loads(rv.text)


import os.path

from ._version import get_versions
VERSION = get_versions()['version']
del get_versions

from .utils import requests_retry_session

API_VERSION = os.getenv('CSIRTG_API_VERSION', '2')

REMOTE = 'https://csirtg.io/api'
REMOTE = os.getenv('CSIRTG_REMOTE', REMOTE)

TOKEN = os.getenv('CSIRTG_TOKEN', None)

TIMEOUT = os.getenv('CSIRTG_TIMEOUT', 30)

LOG_FORMAT = '%(asctime)s - %(levelname)s - %(name)s[%(lineno)s] - %(message)s'

HEADERS = {
    'User-Agent': 'csirtgsdk-py/' + VERSION,
    'x-api-key': TOKEN,
    'Content-Type': 'application/json',
    'Accept-Encoding': 'deflate',
    'Accept': 'application/vnd.csirtg.v' + API_VERSION
}

CACHE_MAX_SIZE = os.getenv('CSIRTG_CACHE_MAX_SIZE', 1024)
CACHE_TTL = os.getenv('CSIRTG_CACHE_TTL', 3600)

SESSION = requests_retry_session()
SESSION.headers = HEADERS



#!/usr/bin/env python3

import logging
import textwrap
from argparse import ArgumentParser
from argparse import RawDescriptionHelpFormatter
from json import dumps
from pprint import pprint

from csirtgsdk import risk, get_feed, create_indicator

logger = logging.getLogger(__name__)


def get():  # pragma: no cover
    p = ArgumentParser(
        description=textwrap.dedent('''\
        example usage:
            $ csirtg 1.1.1.1
            $ csirtg csirtgadgets/ssh-scanners
        '''),
        formatter_class=RawDescriptionHelpFormatter,
        prog='csirtg',
    )

    p.add_argument('q', help='search for indicator or feed')
    p.add_argument('-v', '--verbose', help='search in verbose mode',
                   action='store_true', default=False)

    args = p.parse_args()

    if '/' in args.q:
        data = get_feed(args.q)
    else:
        data = risk(args.q, args.verbose)

    print(dumps(data, indent=4))


def create():  # pragma: no cover
    p = ArgumentParser(
        description=textwrap.dedent('''\
        example usage:
            $ csirtg-create 1.1.1.1 --tags scanner
        '''),
        formatter_class=RawDescriptionHelpFormatter,
        prog='csirtg',
    )

    p.add_argument('i', help='indicator to create')
    p.add_argument('--tags', required=True)
    p.add_argument('--confidence', type=int, default=3)
    p.add_argument('--description', help='description', required=True)
    p.add_argument('--feed', help='feed name (eg: csirtgadgets/ssh-scannerss',
                   required=True)

    args = p.parse_args()

    resp = create_indicator(args.feed, args.i, args.tags, args.description)

    pprint(resp)


if __name__ == "__main__":
    get()



import requests
import os
from requests.adapters import HTTPAdapter
from urllib3.util.retry import Retry

RETRIES = os.getenv('CSIRTGSDK_RETRIES', 5)
BACKOFF = os.getenv('CSIRTGSDK_BACKOFF', 0.5)

ALLOWED = frozenset({'GET', 'OPTIONS', 'POST', 'HEAD'})


def requests_retry_session(retries=RETRIES, backoff_factor=BACKOFF,
                           status_forcelist=(429, 504),
                           session=None):

    session = session or requests.Session()
    retry = Retry(total=int(retries), method_whitelist=ALLOWED,
                  read=int(retries), connect=int(retries),
                  backoff_factor=float(backoff_factor),
                  status_forcelist=status_forcelist)

    adapter = HTTPAdapter(max_retries=retry, pool_connections=128,
                          pool_maxsize=128)
    session.mount('http://', adapter)
    session.mount('https://', adapter)
    return session



import pytest
from csirtgsdk import risk, search
import responses
from csirtgsdk.constants import REMOTE

from pprint import pprint


@responses.activate
def test_http_risk():
    data = {'first_at': '', 'risk': 'unlikely'}
    responses.add(responses.GET, REMOTE + '/risk',
                  json=data, status=200,
                  headers={'Content-Length': '2'})

    rv = risk('1.1.1.1')
    assert rv == data


@responses.activate
def test_http_risk():
    data = {'first_at': '', 'risk': 'unlikely'}
    responses.add(responses.GET, REMOTE + '/search',
                  json=data, status=200,
                  headers={'Content-Length': '2'})

    rv = search('1.1.1.1')
    assert rv == data



from .constants import SESSION, REMOTE
from datetime import datetime
from json import loads, dumps


def create(feed, indicator, tags, description, **kwargs):
    user, feed = feed.split('/')
    uri = REMOTE + f'/users/{user}/feeds/{feed}/indicators'

    rv = SESSION.post(uri, data=dumps({
        'indicator': indicator,
        'tags': tags,
        'description': description,
        'portlist': kwargs.get('portlist'),
        'count': kwargs.get('count', 1),
        'last_at': kwargs.get('last_at', datetime.now().isoformat())
    }))
    if rv.status_code == 500:
        raise ConnectionError('Something is wrong on the server end')

    return loads(rv.text)



from setuptools import setup, find_packages
import os
import sys
import versioneer


# https://www.pydanny.com/python-dot-py-tricks.html
if sys.argv[-1] == 'test':

    r = os.system('pytest test -v && '
                  'xenon -b A -m A -a A -e "csirtgsdk/_version*" csirtgsdk')
    if r == 0:
        raise SystemExit

    raise RuntimeError('tests failed')

setup(
    name="csirtgsdk",
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description="CSIRTG Python SDK",
    long_description="CSIRTG Software Development Kit for Python",
    url="https://github.com/csirtgadgets/csirtgsdk-v2-py",
    license='MPL2',
    classifiers=[
        "Topic :: System :: Networking",
        "Environment :: Other Environment",
        "Intended Audience :: Developers",
        "Programming Language :: Python"
    ],
    keywords=['network', 'security'],
    author="Wes Young",
    author_email="wes@csirtgadgets.com",
    packages=find_packages(exclude=['test']),
    install_requires=[
        'requests',
        'cachetools'
    ],
    entry_points={
        'console_scripts': [
            "csirtg=csirtgsdk.cli:get",
            'csirtg-create=csirtgsdk.cli:create'
        ]
    },
)
